@@ -5,6 +5,7 @@ import (
 	"context"
 
 	"helm.sh/helm/v3/pkg/getter"
+	"helm.sh/helm/v3/pkg/registry"
 )
 
 // URLGetter is an interface to support GET to the specified URL.
@@ -23,14 +24,13 @@ type InstallChartOpts struct {
 	ReleaseName     string
 	Values          map[string]interface{}
 	Version         string
+	RegistryClient  *registry.Client
 }
 
 // HelmInstaller deals with setting up Helm related resources.
 //go:generate go run github.com/maxbrunsfeld/counterfeiter/v6 -generate
 //counterfeiter:generate -o fakes/fake_helm_installer.go . HelmInstaller
 type HelmInstaller interface {
-	// AddRepo adds a repository to helm repositories.
-	AddRepo(repoURL string, release string) error
 	// InstallChart takes a releaseName's name and a chart name and installs it. If namespace is not empty
 	// it will install into that namespace and create the namespace. Version is required.
 	InstallChart(ctx context.Context, opts InstallChartOpts) error
